{
    "$graph": [
        {
            "class": "Workflow",
            "label": "umi molecular alignment workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/bam"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.1,
                    "id": "#main/max_base_error_rate"
                },
                {
                    "type": "float",
                    "default": 0.5,
                    "id": "#main/max_no_call_fraction"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.05,
                    "id": "#main/max_read_error_rate"
                },
                {
                    "type": "int",
                    "default": 1,
                    "id": "#main/min_base_quality"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "int"
                    },
                    "default": [
                        1
                    ],
                    "id": "#main/min_reads"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/read_structure"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict",
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa"
                    ],
                    "id": "#main/reference"
                },
                {
                    "type": "string",
                    "id": "#main/sample_name"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#main/target_intervals"
                }
            ],
            "steps": [
                {
                    "scatter": "#main/align/bam",
                    "run": "#umi_alignment.cwl",
                    "in": [
                        {
                            "source": "#main/bam",
                            "id": "#main/align/bam"
                        },
                        {
                            "source": "#main/read_structure",
                            "id": "#main/align/read_structure"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/align/reference"
                        }
                    ],
                    "out": [
                        "#main/align/aligned_bam",
                        "#main/align/adapter_metrics"
                    ],
                    "id": "#main/align"
                },
                {
                    "run": "#realign.cwl",
                    "in": [
                        {
                            "source": "#main/call_molecular_consensus/consensus_bam",
                            "id": "#main/align_consensus/bam"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/align_consensus/reference"
                        }
                    ],
                    "out": [
                        "#main/align_consensus/consensus_aligned_bam"
                    ],
                    "id": "#main/align_consensus"
                },
                {
                    "run": "#call_molecular_consensus.cwl",
                    "in": [
                        {
                            "source": "#main/group_reads_by_umi/grouped_bam",
                            "id": "#main/call_molecular_consensus/bam"
                        }
                    ],
                    "out": [
                        "#main/call_molecular_consensus/consensus_bam"
                    ],
                    "id": "#main/call_molecular_consensus"
                },
                {
                    "run": "#clip_overlap.cwl",
                    "in": [
                        {
                            "source": "#main/filter_consensus/filtered_bam",
                            "id": "#main/clip_overlap/bam"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/clip_overlap/reference"
                        }
                    ],
                    "out": [
                        "#main/clip_overlap/clipped_bam"
                    ],
                    "id": "#main/clip_overlap"
                },
                {
                    "run": "#duplex_seq_metrics.cwl",
                    "in": [
                        {
                            "source": "#main/group_reads_by_umi/grouped_bam",
                            "id": "#main/collect_duplex_seq_metrics/bam"
                        },
                        {
                            "source": "#main/sample_name",
                            "id": "#main/collect_duplex_seq_metrics/description"
                        },
                        {
                            "source": "#main/target_intervals",
                            "id": "#main/collect_duplex_seq_metrics/intervals"
                        }
                    ],
                    "out": [
                        "#main/collect_duplex_seq_metrics/duplex_seq_metrics"
                    ],
                    "id": "#main/collect_duplex_seq_metrics"
                },
                {
                    "run": "#filter_consensus.cwl",
                    "in": [
                        {
                            "source": "#main/align_consensus/consensus_aligned_bam",
                            "id": "#main/filter_consensus/bam"
                        },
                        {
                            "source": "#main/max_base_error_rate",
                            "id": "#main/filter_consensus/max_base_error_rate"
                        },
                        {
                            "source": "#main/max_no_call_fraction",
                            "id": "#main/filter_consensus/max_no_call_fraction"
                        },
                        {
                            "source": "#main/max_read_error_rate",
                            "id": "#main/filter_consensus/max_read_error_rate"
                        },
                        {
                            "source": "#main/min_base_quality",
                            "id": "#main/filter_consensus/min_base_quality"
                        },
                        {
                            "source": "#main/min_reads",
                            "id": "#main/filter_consensus/min_reads"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/filter_consensus/reference"
                        }
                    ],
                    "out": [
                        "#main/filter_consensus/filtered_bam"
                    ],
                    "id": "#main/filter_consensus"
                },
                {
                    "run": "#group_reads.cwl",
                    "in": [
                        {
                            "source": "#main/merge/merged_bam",
                            "id": "#main/group_reads_by_umi/bam"
                        }
                    ],
                    "out": [
                        "#main/group_reads_by_umi/grouped_bam"
                    ],
                    "id": "#main/group_reads_by_umi"
                },
                {
                    "run": "#index_bam.cwl",
                    "in": [
                        {
                            "source": "#main/clip_overlap/clipped_bam",
                            "id": "#main/index_bam/bam"
                        }
                    ],
                    "out": [
                        "#main/index_bam/indexed_bam"
                    ],
                    "id": "#main/index_bam"
                },
                {
                    "run": "#merge_bams.cwl",
                    "in": [
                        {
                            "source": "#main/align/aligned_bam",
                            "id": "#main/merge/bams"
                        }
                    ],
                    "out": [
                        "#main/merge/merged_bam"
                    ],
                    "id": "#main/merge"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/align/adapter_metrics",
                    "id": "#main/adapter_histogram"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai",
                        "^.bai"
                    ],
                    "outputSource": "#main/index_bam/indexed_bam",
                    "id": "#main/aligned_bam"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/collect_duplex_seq_metrics/duplex_seq_metrics",
                    "id": "#main/duplex_seq_metrics"
                }
            ]
        },
        {
            "class": "Workflow",
            "label": "umi per-lane alignment subworkflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#umi_alignment.cwl/bam"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#umi_alignment.cwl/read_structure"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa"
                    ],
                    "id": "#umi_alignment.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#umi_alignment.cwl/mark_illumina_adapters/metrics",
                    "id": "#umi_alignment.cwl/adapter_metrics"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "outputSource": "#umi_alignment.cwl/align/aligned_bam",
                    "id": "#umi_alignment.cwl/aligned_bam"
                }
            ],
            "steps": [
                {
                    "run": "#umi_align.cwl",
                    "in": [
                        {
                            "source": "#umi_alignment.cwl/mark_illumina_adapters/marked_bam",
                            "id": "#umi_alignment.cwl/align/bam"
                        },
                        {
                            "source": "#umi_alignment.cwl/reference",
                            "id": "#umi_alignment.cwl/align/reference"
                        }
                    ],
                    "out": [
                        "#umi_alignment.cwl/align/aligned_bam"
                    ],
                    "id": "#umi_alignment.cwl/align"
                },
                {
                    "run": "#extract_umis.cwl",
                    "in": [
                        {
                            "source": "#umi_alignment.cwl/bam",
                            "id": "#umi_alignment.cwl/extract_umis/bam"
                        },
                        {
                            "source": "#umi_alignment.cwl/read_structure",
                            "id": "#umi_alignment.cwl/extract_umis/read_structure"
                        }
                    ],
                    "out": [
                        "#umi_alignment.cwl/extract_umis/umi_extracted_bam"
                    ],
                    "id": "#umi_alignment.cwl/extract_umis"
                },
                {
                    "run": "#mark_illumina_adapters.cwl",
                    "in": [
                        {
                            "source": "#umi_alignment.cwl/extract_umis/umi_extracted_bam",
                            "id": "#umi_alignment.cwl/mark_illumina_adapters/bam"
                        }
                    ],
                    "out": [
                        "#umi_alignment.cwl/mark_illumina_adapters/marked_bam",
                        "#umi_alignment.cwl/mark_illumina_adapters/metrics"
                    ],
                    "id": "#umi_alignment.cwl/mark_illumina_adapters"
                }
            ],
            "id": "#umi_alignment.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "call molecular consensus",
            "baseCommand": [
                "/usr/local/bin/fgbio",
                "CallMolecularConsensusReads"
            ],
            "arguments": [
                "--error-rate-pre-umi",
                "45",
                "--error-rate-post-umi",
                "30",
                "--min-input-base-quality",
                "30",
                "--min-reads",
                "1",
                "--output",
                {
                    "valueFrom": "$(runtime.outdir)/consensus_unaligned.bam"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/fgbio:1.3.0--0"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input"
                    },
                    "id": "#call_molecular_consensus.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "consensus_unaligned.bam"
                    },
                    "id": "#call_molecular_consensus.cwl/consensus_bam"
                }
            ],
            "id": "#call_molecular_consensus.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "clip overlapping reads",
            "baseCommand": [
                "/usr/local/bin/fgbio",
                "ClipBam"
            ],
            "arguments": [
                "--clipping-mode",
                "Hard",
                "--clip-overlapping-reads",
                "true",
                "--output",
                {
                    "valueFrom": "$(runtime.outdir)/clipped.bam"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/fgbio:1.3.0--0"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input"
                    },
                    "id": "#clip_overlap.cwl/bam"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "--ref"
                    },
                    "id": "#clip_overlap.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "outputBinding": {
                        "glob": "clipped.bam"
                    },
                    "id": "#clip_overlap.cwl/clipped_bam"
                }
            ],
            "id": "#clip_overlap.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "collect duplex seq metrics",
            "baseCommand": [
                "/usr/local/bin/fgbio",
                "CollectDuplexSeqMetrics"
            ],
            "arguments": [
                "--output",
                {
                    "valueFrom": "$(runtime.outdir)/duplex_seq.metrics"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 1000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/fgbio:1.3.0--0"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input"
                    },
                    "id": "#duplex_seq_metrics.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--description"
                    },
                    "id": "#duplex_seq_metrics.cwl/description"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--intervals"
                    },
                    "id": "#duplex_seq_metrics.cwl/intervals"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "duplex_seq.metrics.*"
                    },
                    "id": "#duplex_seq_metrics.cwl/duplex_seq_metrics"
                }
            ],
            "id": "#duplex_seq_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "extract umis from bam",
            "baseCommand": [
                "/usr/local/bin/fgbio",
                "ExtractUmisFromBam"
            ],
            "arguments": [
                "--molecular-index-tags",
                "ZA",
                "ZB",
                "--single-tag",
                "RX",
                "--output",
                {
                    "valueFrom": "$(runtime.outdir)/umi_extracted.bam"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/fgbio:1.3.0--0"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input"
                    },
                    "id": "#extract_umis.cwl/bam"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "inputBinding": {
                        "prefix": "--read-structure"
                    },
                    "id": "#extract_umis.cwl/read_structure"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "umi_extracted.bam"
                    },
                    "id": "#extract_umis.cwl/umi_extracted_bam"
                }
            ],
            "id": "#extract_umis.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "filter consensus reads",
            "baseCommand": [
                "/usr/local/bin/fgbio",
                "FilterConsensusReads"
            ],
            "arguments": [
                "--output",
                {
                    "valueFrom": "$(runtime.outdir)/consensus_filtered.bam"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/fgbio:1.3.0--0"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input"
                    },
                    "id": "#filter_consensus.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "--max-base-error-rate"
                    },
                    "id": "#filter_consensus.cwl/max_base_error_rate"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "--max-no-call-fraction"
                    },
                    "id": "#filter_consensus.cwl/max_no_call_fraction"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "--max-read-error-rate"
                    },
                    "id": "#filter_consensus.cwl/max_read_error_rate"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "--min-base-quality"
                    },
                    "id": "#filter_consensus.cwl/min_base_quality"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "int"
                    },
                    "inputBinding": {
                        "prefix": "--min-reads"
                    },
                    "id": "#filter_consensus.cwl/min_reads"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "--ref"
                    },
                    "id": "#filter_consensus.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "consensus_filtered.bam"
                    },
                    "id": "#filter_consensus.cwl/filtered_bam"
                }
            ],
            "id": "#filter_consensus.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "group reads by umi",
            "baseCommand": [
                "/usr/local/bin/fgbio",
                "GroupReadsByUmi"
            ],
            "arguments": [
                "--strategy",
                "paired",
                "--assign-tag",
                "MI",
                "--raw-tag",
                "RX",
                "--min-map-q",
                "10",
                "--edits",
                "1",
                "--output",
                {
                    "valueFrom": "$(runtime.outdir)/umi_grouped.bam"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/fgbio:1.3.0--0"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input"
                    },
                    "id": "#group_reads.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "umi_grouped.bam"
                    },
                    "id": "#group_reads.cwl/grouped_bam"
                }
            ],
            "id": "#group_reads.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools index",
            "arguments": [
                "/usr/local/bin/samtools",
                "index",
                "$(runtime.outdir)/$(inputs.bam.basename)",
                "$(runtime.outdir)/$(inputs.bam.basename).bai",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "cp",
                "$(inputs.bam.basename).bai",
                "$(runtime.outdir)/$(inputs.bam.nameroot).bai"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/samtools:1.11--h6270b1f_0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        "${ var f = inputs.bam; delete f.secondaryFiles; return f }"
                    ]
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#index_bam.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai",
                        "^.bai"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.bam.basename)"
                    },
                    "id": "#index_bam.cwl/indexed_bam"
                }
            ],
            "id": "#index_bam.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "fastq to bam",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/picard/picard.jar",
                "MarkIlluminaAdapters"
            ],
            "arguments": [
                "OUTPUT=",
                {
                    "valueFrom": "$(runtime.outdir)/marked.bam"
                },
                "METRICS=",
                {
                    "valueFrom": "$(runtime.outdir)/adapter_metrics.txt"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/dna-alignment:1.0.0"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "INPUT=",
                        "position": 1
                    },
                    "id": "#mark_illumina_adapters.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "marked.bam"
                    },
                    "id": "#mark_illumina_adapters.cwl/marked_bam"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "adapter_metrics.txt"
                    },
                    "id": "#mark_illumina_adapters.cwl/metrics"
                }
            ],
            "id": "#mark_illumina_adapters.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Sambamba: merge",
            "baseCommand": [
                "/bin/bash",
                "merge.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000,
                    "coresMin": 4
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/bam-merge:0.1"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "merge.sh",
                            "entry": "#!/bin/bash\nset -o pipefail\nset -o errexit\nset -o nounset\n\nSORTED=false\n\nwhile getopts \"t:n:s:\" opt; do\n    case \"$opt\" in\n        t)\n            NTHREADS=\"$OPTARG\"\n            ;;\n        n)\n            OUTFILENAME=\"$OPTARG\"\n            ;;\n        s)\n            SORTED=true\n            ;;\n    esac\ndone\n\nBAMS=(\"${@:$OPTIND}\")\nNUM_BAMS=${#BAMS[@]}\n\n#if there is only one bam, just copy it and index it\nif [[ $NUM_BAMS -eq 1 ]]; then\n    cp \"$BAMS\" \"$OUTFILENAME\";\nelse\n    if [[ $SORTED == \"true\" ]];then\n        /usr/bin/sambamba merge -t \"$NTHREADS\" \"$OUTFILENAME\" \"${BAMS[@]}\"\n    else #unsorted bams, use picard\n        args=(OUTPUT=\"$OUTFILENAME\" ASSUME_SORTED=true USE_THREADING=true SORT_ORDER=unsorted VALIDATION_STRINGENCY=LENIENT)\n        for i in \"${BAMS[@]}\";do\n          args+=(\"INPUT=$i\")\n        done\n        java -jar -Xmx6g /opt/picard/picard.jar MergeSamFiles \"${args[@]}\"\n    fi\nfi\nif [[ $SORTED == \"true\" ]];then\n  /usr/bin/sambamba index \"$OUTFILENAME\"\nfi\n"
                        }
                    ]
                }
            ],
            "arguments": [
                "-t",
                "$(runtime.cores)"
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#merge_bams.cwl/bams"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "merged.bam",
                    "inputBinding": {
                        "prefix": "-n",
                        "position": 1
                    },
                    "id": "#merge_bams.cwl/name"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": "false",
                    "inputBinding": {
                        "prefix": "-s",
                        "position": 2
                    },
                    "id": "#merge_bams.cwl/sorted"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.name)"
                    },
                    "id": "#merge_bams.cwl/merged_bam"
                }
            ],
            "id": "#merge_bams.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "umi realignment",
            "baseCommand": [
                "/bin/bash",
                "/usr/bin/umi_realignment.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000,
                    "coresMin": 8
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/dna-alignment:1.0.0"
                }
            ],
            "arguments": [
                {
                    "position": 3,
                    "valueFrom": "$(runtime.cores)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#realign.cwl/bam"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa"
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#realign.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "outputBinding": {
                        "glob": "realigned.bam"
                    },
                    "id": "#realign.cwl/consensus_aligned_bam"
                }
            ],
            "id": "#realign.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "umi alignment",
            "baseCommand": [
                "/bin/bash",
                "/usr/bin/umi_alignment.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000,
                    "coresMin": 8
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/dna-alignment:1.0.0"
                }
            ],
            "arguments": [
                {
                    "position": 3,
                    "valueFrom": "$(runtime.cores)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#umi_align.cwl/bam"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa"
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#umi_align.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "outputBinding": {
                        "glob": "aligned.bam"
                    },
                    "id": "#umi_align.cwl/aligned_bam"
                }
            ],
            "id": "#umi_align.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
